==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/table/lang/oc.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'oc', {
	border: 'Talha de la bordadura',
	caption: 'Títol del tablèu',
	cell: {
		menu: 'Cellula',
		insertBefore: 'Inserir una cellula abans',
		insertAfter: 'Inserir una cellula aprèp',
		deleteCell: 'Suprimir las cellulas',
		merge: 'Fusionar las cellulas',
		mergeRight: 'Fusionar cap a dreita',
		mergeDown: 'Fusionar cap aval',
		splitHorizontal: 'Separar la cellula orizontalament',
		splitVertical: 'Separar la cellula verticalament',
		title: 'Proprietats de la cellula',
		cellType: 'Tipe de cellula',
		rowSpan: 'Linhas ocupadas',
		colSpan: 'Colomnas ocupadas',
		wordWrap: 'Cesura',
		hAlign: 'Alinhament orizontal',
		vAlign: 'Alinhament vertical',
		alignBaseline: 'Linha de basa',
		bgColor: 'Color de rèireplan',
		borderColor: 'Color de bordadura',
		data: 'Donadas',
		header: 'Entèsta',
		yes: 'Òc',
		no: 'Non',
		invalidWidth: 'La largor de la cellula deu èsser un nombre.',
		invalidHeight: 'La nautor de la cellula deu èsser un nombre.',
		invalidRowSpan: 'Lo nombre de linhas ocupadas deu èsser un nombre entièr.',
		invalidColSpan: 'Lo nombre de colomnas ocupadas deu èsser un nombre entièr.',
		chooseColor: 'Causir'
	},
	cellPad: 'Marge intèrne de las cellulas',
	cellSpace: 'Espaçament entre las cellulas',
	column: {
		menu: 'Colomna',
		insertBefore: 'Inserir una colomna abans',
		insertAfter: 'Inserir una colomna aprèp',
		deleteColumn: 'Suprimir las colomnas'
	},
	columns: 'Colomnas',
	deleteTable: 'Suprimir lo tablèu',
	headers: 'Entèstas',
	headersBoth: 'Los dos',
	headersColumn: 'Primièra colomna',
	headersNone: 'Pas cap',
	headersRow: 'Primièra linha',
	invalidBorder: 'La talha de la bordadura deu èsser un nombre.',
	invalidCellPadding: 'Lo marge intèrne de las cellulas deu èsser un nombre positiu.',
	invalidCellSpacing: 'L\'espaçament entre las cellulas deu èsser un nombre positiu.',
	invalidCols: 'Lo nombre de colomnas deu èsser superior a 0.',
	invalidHeight: 'La nautor del tablèu deu èsser un nombre.',
	invalidRows: 'Lo nombre de linhas deu èsser superior a 0.',
	invalidWidth: 'La largor del tablèu deu èsser un nombre.',
	menu: 'Proprietats del tablèu',
	row: {
		menu: 'Linha',
		insertBefore: 'Inserir una linha abans',
		insertAfter: 'Inserir una linha aprèp',
		deleteRow: 'Suprimir las linhas'
	},
	rows: 'Linhas',
	summary: 'Resumit (descripcion)',
	title: 'Proprietats del tablèu',
	toolbar: 'Tablèu',
	widthPc: 'per cent',
	widthPx: 'pixèls',
	widthUnit: 'unitat de largor'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/oc.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'oc', {
	border: 'Talha de la bordadura',
	caption: 'Títol del tablèu',
	cell: {
		menu: 'Cellula',
		insertBefore: 'Inserir una cellula abans',
		insertAfter: 'Inserir una cellula aprèp',
		deleteCell: 'Suprimir las cellulas',
		merge: 'Fusionar las cellulas',
		mergeRight: 'Fusionar cap a dreita',
		mergeDown: 'Fusionar cap aval',
		splitHorizontal: 'Separar la cellula orizontalament',
		splitVertical: 'Separar la cellula verticalament',
		title: 'Proprietats de la cellula',
		cellType: 'Tipe de cellula',
		rowSpan: 'Linhas ocupadas',
		colSpan: 'Colomnas ocupadas',
		wordWrap: 'Cesura',
		hAlign: 'Alinhament orizontal',
		vAlign: 'Alinhament vertical',
		alignBaseline: 'Linha de basa',
		bgColor: 'Color de rèireplan',
		borderColor: 'Color de bordadura',
		data: 'Donadas',
		header: 'Entèsta',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Òc',
		no: 'Non',
		invalidWidth: 'La largor de la cellula deu èsser un nombre.',
		invalidHeight: 'La nautor de la cellula deu èsser un nombre.',
		invalidRowSpan: 'Lo nombre de linhas ocupadas deu èsser un nombre entièr.',
		invalidColSpan: 'Lo nombre de colomnas ocupadas deu èsser un nombre entièr.',
		chooseColor: 'Causir'
	},
	cellPad: 'Marge intèrne de las cellulas',
	cellSpace: 'Espaçament entre las cellulas',
	column: {
		menu: 'Colomna',
		insertBefore: 'Inserir una colomna abans',
		insertAfter: 'Inserir una colomna aprèp',
		deleteColumn: 'Suprimir las colomnas'
	},
	columns: 'Colomnas',
	deleteTable: 'Suprimir lo tablèu',
	headers: 'Entèstas',
	headersBoth: 'Los dos',
	headersColumn: 'Primièra colomna',
	headersNone: 'Pas cap',
	headersRow: 'Primièra linha',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'La talha de la bordadura deu èsser un nombre.',
	invalidCellPadding: 'Lo marge intèrne de las cellulas deu èsser un nombre positiu.',
	invalidCellSpacing: 'L\'espaçament entre las cellulas deu èsser un nombre positiu.',
	invalidCols: 'Lo nombre de colomnas deu èsser superior a 0.',
	invalidHeight: 'La nautor del tablèu deu èsser un nombre.',
	invalidRows: 'Lo nombre de linhas deu èsser superior a 0.',
	invalidWidth: 'La largor del tablèu deu èsser un nombre.',
	menu: 'Proprietats del tablèu',
	row: {
		menu: 'Linha',
		insertBefore: 'Inserir una linha abans',
		insertAfter: 'Inserir una linha aprèp',
		deleteRow: 'Suprimir las linhas'
	},
	rows: 'Linhas',
	summary: 'Resumit (descripcion)',
	title: 'Proprietats del tablèu',
	toolbar: 'Tablèu',
	widthPc: 'per cent',
	widthPx: 'pixèls',
	widthUnit: 'unitat de largor'
} );
